@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2011  Innocent De Marchi
+ * Copyright (C) 2000-2012  Innocent De Marchi
  * email: tangram.peces@gmail.com
  *
  * This program is free software; you can redistribute it and/or modify
@@ -54,6 +54,7 @@ public:
     void carregaPuntuacio();
     void desaPuntuacio(QString pTemps);
 
+
     /**
          * Tipus de tangram que es juga
          * Per defecte el tangram classic
@@ -108,6 +109,11 @@ public:
 
         QString directoriArxiuDadesFigures;
 
+        /* 07/02/12 v. 5.0
+          Retorna el camí complet de l'arxiu de figures.
+          */
+        QString ArxiuDadesFigures();
+
         /*
          Gestiona la conservació de la configuració a un arxiu
         */
@@ -152,6 +158,8 @@ public:
     Mostra la pàgina web de "registre" de l'aplicació
     */
       bool registraAplicacio();
+
+
 };
 
 #endif // CONFIGURACIO_H
