@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2011  Innocent De Marchi
+ * Copyright (C) 2000-2012  Innocent De Marchi
  * email: tangram.peces@gmail.com
  *
  * This program is free software; you can redistribute it and/or modify
@@ -365,12 +365,17 @@ static const float ESCALA_MOSTRA =  15.0;
 
 static const int PERCENTATGE_COINCIDENCIA_SOLUCIO=95;
 static const double DISTANCIA_PUNTS_SOLUCIO=3.0;
-static const float PERCENTATGE_COINCIDENCIA_BUSCAR_FIGURA =  90.0;
+/*13/01/12
+  Amb els canvis en la comparació de figures,
+  s'ha pujat aquest valor
+  (estava a 90.0)
+  */
+static const float PERCENTATGE_COINCIDENCIA_BUSCAR_FIGURA =  95.0;
 
 /*
   Nivells del joc
  (No pot començar per 0 ja que es fa servir per calcular
-     //la puntuació de cada figura)
+  la puntuació de cada figura)
 */
 static const int NIVELL_INFANTIL=1;
 static const int NIVELL_PRINCIPIANT=2;
@@ -386,7 +391,7 @@ static const QString NOM_NIVELL_EXPERT="nivell.expert";
 
 
 
-//Angle de rotacio (en graus) de les Peces
+      //Angle de rotacio (en graus) de les Peces
      //(segons el nivell de joc)
      static const double ROTACIO_INFANTIL=45.0;
      static const double ROTACIO_PRINCIPIANT=45.0;
@@ -430,16 +435,19 @@ static const qreal transparencia=0.6;
   Adreça de registre de l'aplicació
 */
 //const QString ADRECA_WEB_REGISTRE="http://www.mallorcaweb.net/tangrampeces/applet/provesappletpeces.html";
-const QString ADRECA_WEB_REGISTRE="http://www.mallorcaweb.net/tangrampeces/jpeces_reg.html";
-const QString ADRECA_WEB_PROGRAMA="http://www.mallorcaweb.net/tangrampeces/";
+const QString ADRECA_WEB_REGISTRE="http://pecesjocdetangr.sourceforge.net/jpeces_reg.html";
+const QString ADRECA_WEB_PROGRAMA="http://pecesjocdetangr.sourceforge.net/";
+const QString ADRECA_ARXIU_VERSIO="http://pecesjocdetangr.sourceforge.net/versio";
 const QString ADRECA_CORREU="tangram.peces@gmail.com";
 
 /*
   Directoris
- */
+21/04/11 Eliminat per innecessari. Només es fa servir
+a funcions.directoriLinux()
 const QString DIRECTORIS_LINUX="/usr/share/games/glpeces";
 const QString DIRECTORIS_LINUX_PROGRAMA="/games";
 const QString DIRECTORIS_LINUX_AUXILIARS="/share/games/glpeces";
+*/
 
 const QString DIR_HELP="help";
 
