@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2011  Innocent De Marchi
+ * Copyright (C) 2000-2012  Innocent De Marchi
  * email: tangram.peces@gmail.com
  *
  * This program is free software; you can redistribute it and/or modify
@@ -266,7 +266,6 @@ else {
 //botons
 void CreaConcurs::afegeixFiguraSlot(){
  QApplication::setOverrideCursor(Qt::WaitCursor);
-
  if( arbreFiguresTreeWidget->selectedItems().count()>0){
  QTreeWidgetItem *item=arbreFiguresTreeWidget->selectedItems().first();
 
@@ -326,10 +325,18 @@ arbreFiguresTreeWidget->topLevelItem(0)->setText(0,configuracioJoc->tradueixCade
 
 void CreaConcurs::concursAtzarSlot(){
 bool val;
-int nombreFigures = QInputDialog::getInteger(this, configuracioJoc->tradueixCadena("nombre.Figures"),
+/* 27/11/11
+  Canviat degut a un canvi a Qt
+  */
+/*int nombreFigures = QInputDialog::getInteger(this, configuracioJoc->tradueixCadena("nombre.Figures"),
+                                configuracioJoc->tradueixCadena("Nombre.figures.seleccionar"),
+                                qMin(25,arbreFiguresTreeWidget->topLevelItem(0)->childCount()),
+                                1,arbreFiguresTreeWidget->topLevelItem(0)->childCount(), 1, &val);*/
+int nombreFigures = QInputDialog::getInt(this, configuracioJoc->tradueixCadena("nombre.Figures"),
                                 configuracioJoc->tradueixCadena("Nombre.figures.seleccionar"),
                                 qMin(25,arbreFiguresTreeWidget->topLevelItem(0)->childCount()),
                                 1,arbreFiguresTreeWidget->topLevelItem(0)->childCount(), 1, &val);
+
 if (val){
   if(arbreFiguresTreeWidget->topLevelItem(0)->childCount()>0){
    for(int j=0;j<=nombreFigures-1;j++){
