@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2011  Innocent De Marchi
+ * Copyright (C) 2000-2012  Innocent De Marchi
  * email: tangram.peces@gmail.com
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,9 +19,12 @@
 #ifndef FORMULARIPRINCIPAL_H
 #define FORMULARIPRINCIPAL_H
 
+#include <QNetworkAccessManager>
+
 #include "comuns/constants.h"
 #include "comuns/rellotge.h"
 #include "formularis/desafigura.h"
+
 class Peca;
 class ConjuntPeces;
 class Configuracio;
@@ -66,6 +69,22 @@ public:
 
     QStringList nomsDelsJocsPerTraduccio;
 
+
+    /* 26/10/11
+       Comprovació d'actualitzacions
+      */
+    QFile output;
+    QNetworkReply *currentDownload;
+    QNetworkAccessManager manager;
+
+    /*
+      Generació automàtica de noves figures
+      */
+    int nivellFiguresAutomatiques;
+    //Rellotge per fer de llavor en els
+    //càlculs de nombres aleatoris
+    QTime rellotgeAtzar;
+
 private slots:
 
 
@@ -79,7 +98,12 @@ private slots:
    /*  4.0.2
        Elimina les dades de la solució obtinguda per l'usuari
        */
-    void seleccionFiguraItemDoubleClicked(QTreeWidgetItem * item, int column);
+    /*
+      16/12/11
+      Eliminat el paràmetre column que no es fa servir
+      */
+    //void seleccionFiguraItemDoubleClicked(QTreeWidgetItem * item, int column);
+    void seleccionFiguraItemDoubleClicked(QTreeWidgetItem * item);
 
     /* 4.1 28/01/11
        Retorna el % de la solució anterior de la figura
@@ -113,6 +137,8 @@ private slots:
    */
     void creaTangram(int tipusTangram);
 
+    void carregaColorsPersonalitzatsPeces();
+
     /* 20/02/11
       Col·loca les peces en la figura
       "inicial" del tangram*/
@@ -168,11 +194,47 @@ void seleccioIdioma(QAction *action);
   v. 4.0.2
 */
 
+
 //Ajuda
 void ajudaSlot();
 void webProgramaSlot();
 void creditsProgramaSlot();
 void colaboraProgramaSlot();
+void agraimentSlot();
+
+/* 26/10/11
+   Comprovació de nova versió
+  */
+void comprovaVersioSlot();
+void baixaArxiuFinished();
+void baixaArxiuReadyRead();
+
+/*
+  Generació automàtica de noves figures
+  */
+
+void generaFiguraAtzarSlot();
+bool generaNovaFiguraAtzar(bool desaFigura=false);
+void generaFiguresMassiuAtzarSlot();
+void desaFiguraAtzar(QString nom, QString codi);
+void controlaActivacioMenusFiguresAtzar();
+bool controlaArxiuDadesPosicionsPeces();
+void comprovaNovesFiguresAtzarSlot();
+
+void dadesPosicionsPeces(int nivell,int peca1, int peca2);
+QStringList carregaDadesPosicionsPeces();
+QStringList seleccionaDadesPosicionsPeces(QStringList llistaDades2,
+                                          int pecaAColocar2,int pecaColocada2);
+QStringList seleccionaPosicionsCorrectesPeces(QStringList llistaDades3,
+                                              int pecaAColocar3,int pecaColocada3);
+QList<int> generaOrdrePecesGeneracioFiguraAtzar();
+bool generaFiguraAtzar(bool desaFigura=false);
+bool generaFiguraAtzarCompacte(bool desaFigura=false);
+QStringList colocaPecesFiguraAtzar1(QStringList llistaDades1,int pecaAColocar1,int pecaColocada1);
+bool colocaPeca(QStringList llistaDades5, int pecaAColocar5);
+int calculaNivellDificultatFigura();
+
+QString HTML_llicencia();
 
 private:
 
@@ -182,6 +244,9 @@ private:
     //Crea les accions i menus amb
     //els tipus de tangram
     void creaTipusTangramMenu();
+    //retorna una llista amb les dades dels
+    //tangram ordenats pel número de peces
+    QStringList dadesTangram();
     //Retorna una llista
     //amb les dades d'un arxiu
     QStringList  llegeixArxiuALlista(QString arxiu);
@@ -194,7 +259,24 @@ private:
 
     void canviaEstatDelJoc(EstatsDelJoc estat);
 
+    /*
+      Comprova si una figura està ja resolta
+      */
     float figuraSolucionada();
+    /*
+      Compara directament les siluetes per comprovar
+      si són idèntiques
+      */
+    bool comparacioSiluetes();
+    /*
+      Compara les siluetes comprovant si intersecten
+      els paths
+      */
+    bool siluetesIntersecten();
+    //S'ha passat a funcions.h
+    //bool comprovaCentresFigures(ConjuntPeces *conjunt1,
+      //                          ConjuntPeces *conjunt2);
+    bool comparacioLongitudSiluetes();
     //No es fa servir v. 4.1
     //bool figuraSolucionadaNivellInfantil();
 
@@ -248,6 +330,14 @@ private:
      */
    void angleGirConjuntPecesJoc();
 
+
+   /* 26/10/11
+      Comprovació de nova versió
+     Llegeix l'arxiu «versio» i comprova
+     si hi ha una nova versió
+     */
+   QString llegeixNovaVersio();
+
     /*
       Retorna el icone corresponent al nivel de dificultatn
       de la figura
@@ -263,6 +353,7 @@ private:
     QMenu *jocsTangramMenu;
     QMenu *creaFiguraMenu;
     QMenu *concursMenu;
+    QMenu *generaFigures;
     QMenu *idiomaMenu;    
        QActionGroup *idiomaActionGroup;
     QMenu *ajudaMenu;
@@ -339,12 +430,18 @@ QAction *carregaConcursAction;
   Canviat el sistema de gestió del idioma
   v. 4.0.2
     */
+//Generació automàtica de noves figures
+QAction *generaFiguraAtzarAction;
+QAction *generaFiguresMassiuAtzarAction;
+QAction *comprovaFiguresAtzarAction;
 
 //Menu de l'ajuda
     QAction *ajuda;
     QAction *webPrograma;
+    QAction *comprovaVersio;
     QAction *creditsPrograma;
     QAction *colaboraPrograma;
+    QAction *agraiment;
 
     QGraphicsView *viewJoc;
     QGraphicsView *viewMostra;
