@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2011  Innocent De Marchi
+ * Copyright (C) 2000-2012  Innocent De Marchi
  * email: tangram.peces@gmail.com
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,9 +24,9 @@
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
-        app.setApplicationName("Tangram");
-        app.setApplicationVersion("4.1");
-        app.setOrganizationName("De Marchi");
+        app.setApplicationName("Peces (Tangram)");
+        app.setApplicationVersion("5.0");
+        app.setOrganizationName("I. De Marchi");
 
         //Això pels accents a les cadenes
         QTextCodec *linuxCodec = QTextCodec::codecForName("UTF-8");
@@ -41,6 +41,7 @@ int main(int argc, char *argv[])
      app.processEvents();
 
     //Això per a que surtin traduïdes les cadenes dels formularis predefinits Qt
+    //...si tenen instal·lats els arxius .qm
      QString translatorFileName = QLatin1String("qt_");
      translatorFileName += QLocale::system().name();
      QTranslator *translator = new QTranslator(&app);
