@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2011  Innocent De Marchi
+ * Copyright (C) 2000-2012  Innocent De Marchi
  * email: tangram.peces@gmail.com
  *
  * This program is free software; you can redistribute it and/or modify
@@ -46,6 +46,8 @@ public:
 
     double escala;
 
+    int tipusTangram;
+
 
     /*
       Col·loca les peces a l'atzar
@@ -118,6 +120,20 @@ public:
     //construir les peces
    // QStringList dadesPeces;
 
+    /*
+      15/11/11
+      Retorna la silueta de la figura formada
+      per les peces del conjunt
+      (es fa servir per calcular el nivell de dificultad
+      de les figures generades automàticament)
+      */
+    QPainterPath siluetaFigura();
+    qreal longitudTotalPeces;
+    /*
+      Retorna la longitud de la silueta de la figura actual
+      */
+    qreal longitudSilueta();
+
 private:
 
 
