@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2011  Innocent De Marchi
+ * Copyright (C) 2000-2012  Innocent De Marchi
  * email: tangram.peces@gmail.com
  *
  * This program is free software; you can redistribute it and/or modify
@@ -75,13 +75,17 @@ Peca::Peca(int tipusPeca,float posicio_X,float posicio_Y,float angle,
    }
 }
 
+/* 15/10/11
+   Aquest procediment no es fa servir
+*/
 void Peca::colocaPecaAtzar(int maxX,int maxY){
 //Cal evitar que la Peça quedi en algun
 //angle "impossible"
 //reiniciaAnglesVertex(tipusPeca);
+qsrand(pos().x());
 reiniciaAnglesVertex();
 setPos(qrand() % maxX,qrand() % maxY);
-     while  (!pecaEnLimits()){
+     while  (!pecaEnLimits() || pecaSuperposada(false) ){
         setPos(qrand() % maxX,qrand() % maxY);
     }
 }
@@ -90,10 +94,11 @@ void Peca::colocaPecaAtzar(){
 //Cal evitar que la Peça quedi en algun
 //angle "impossible"
 //reiniciaAnglesVertex(tipusPeca);
+qsrand(pos().x());
 reiniciaAnglesVertex();
 setAngleRotacio(normalitzaAngle((rand() % 5+1) * PI/4));
 setPos(qrand() % (int) scene()->width() ,qrand() %  (int) scene()->height());
-    while  (!pecaEnLimits()){
+    while  (!pecaEnLimits() || pecaSuperposada() ){
        setPos(qrand() % (int) scene()->width() ,qrand() %  (int) scene()->height());
     }
 }
@@ -123,12 +128,22 @@ void Peca::mousePressEvent(QGraphicsSceneMouseEvent *event){
 	    if (event->modifiers().testFlag ( Qt::ControlModifier )){
 		simetriaPeca();
                 //comprova si la peça està en els limits de la zona de joc
-                if(!pecaEnLimits()){
+                /* 15/10/11
+                afegit el control de superposició */
+                if(!pecaEnLimits() || pecaSuperposada()) {
+               // if(!pecaEnLimits()){
                     event->ignore();
                     simetriaPeca();
                 }
 		movimentPeca=0;
 	    }
+            else if (event->modifiers().testFlag(Qt::ShiftModifier)){
+                //Personalització del color de la peça
+                setColorPeca(
+                        personalitzaColorPeca(indexEnElConjunt,
+                                              getColorPeca(),conjuntDePeces->tipusTangram));
+                setColorLimits(getColorPeca());
+            }
 	    //la peça es pot moure
             else {
                 movimentPeca=1;
@@ -142,13 +157,23 @@ void Peca::mousePressEvent(QGraphicsSceneMouseEvent *event){
             setSelected(true);
             simetriaPeca();
             //comprova si la peça està en els limits de la zona de joc
-                if(!pecaEnLimits()){
+            /* 15/10/11
+            afegit el control de superposició */
+            if(!pecaEnLimits() || pecaSuperposada()) {
+               // if(!pecaEnLimits()){
                     event->ignore();
                     simetriaPeca();
                 }
 	    movimentPeca=0;
 	}
 	else if (event->button()==Qt::RightButton){
+            if (event->modifiers().testFlag(Qt::ShiftModifier)){
+                //Elimina la personalització del color de la peça
+                eliminaPersonalitzaColorPeca(indexEnElConjunt,
+                                              conjuntDePeces->tipusTangram);
+                colorsAtzarPeca();
+                return;
+            }
             setSelected(true);
 	    //rotació lliure de la peça
             if (angleGirPeca==ROTACIO_EXPERT){
@@ -174,20 +199,31 @@ void Peca::mousePressEvent(QGraphicsSceneMouseEvent *event){
                    girFet=acelera*angleGirPeca*PI/180;
                    }
                 else {
+                    /* 15/10/11
+                       Canviat el signe a girFet per evitar que
+                       a vegades, no funcini correctament
+                       la tornada enrrera si la peça queda superposada
+                      */
                     rotaPeca(-acelera*angleGirPeca*PI/180);
-                    girFet=acelera*angleGirPeca*PI/180;
+                    girFet=-acelera*angleGirPeca*PI/180;
                       }
                 //comprova si la peça està en els limits de la zona de joc
-                if(!pecaEnLimits()){
+                /* 15/10/11
+                afegit el control de superposició */
+                if(!pecaEnLimits() || pecaSuperposada()) {
+                //if(!pecaEnLimits()){
                     event->ignore();
                     rotaPeca(-girFet);
                     movimentPeca=0;
                 }
-                movimentPeca=0;
+                /* 15/10/11
+                afegit per permetre que les peces girin automàticament
+                quan xoquin */
+                movimentPeca=2;
                 }
 	}
  }//final if contains
-//el clic és fora de la silueta de la Peça
+//el clic és  fora de la silueta de la Peça
   else {
     setSelected(false);
     setZValue(0);
@@ -207,21 +243,30 @@ void Peca::mousePressEvent(QGraphicsSceneMouseEvent *event){
 
 void Peca::mouseMoveEvent ( QGraphicsSceneMouseEvent *event){
 if(!pecaMostra){
-  if (shape().contains(event->pos())){
-      if  (movimentPeca==1){
+  /* 23/07/11
+     Això feia que en moure la peça ràpidament,
+     sovint queda aturada. Pareix què també ara permet
+     que en girar, el cursor surti de la peça i fa més fàcil
+     el gir
+    */
+  //if (shape().contains(event->pos())){
+     if (movimentPeca==1){
         QPointF darreraPos=pos();
 	setFlag(QGraphicsItem::ItemIsMovable,true);
 	QGraphicsItem::mouseMoveEvent(event);
-     //   if(!pecaEnLimits() || pecaSuperposada()){
-        if(!pecaEnLimits() ){
+        /* 15/10/11
+        afegit el control de superposició */
+        if(!pecaEnLimits() || pecaSuperposada()){
+        //if(!pecaEnLimits() ){
            event->ignore();
            setPos(darreraPos);
            if (angleGirPeca==ROTACIO_EXPERT){
                movimentPeca=2;
            }
-         }
+           movimentPeca=2;
+         }        
       }
-      else if (movimentPeca==2){
+      else if ( (movimentPeca==2) && (angleGirPeca==ROTACIO_EXPERT) ){
         QPointF centre=centrePeca();//centreRectanglePeca();
        // QPointF centre=centreRectanglePeca();
 	QPointF iniciGir=event->lastPos()-centre;
@@ -236,7 +281,9 @@ if(!pecaMostra){
         if (event->modifiers().testFlag ( Qt::ControlModifier )){
                   precisio=0.2;}
         rotaPeca(precisio*(angleFinal-angleInici));
-        if(!pecaEnLimits()){
+        /* 15/10/11
+        afegit el control de superposició */
+        if(!pecaEnLimits() || pecaSuperposada() ){
            event->ignore();
            rotaPeca(precisio*(-angleFinal+angleInici));
            movimentPeca=1;
@@ -247,16 +294,55 @@ if(!pecaMostra){
 	  rotate(angleGir*180/PI);
 	  translate( -center.x(), -center.y() );
 	*/
+       } // final else if moviment expert
+      /* 15/10/11
+         Afegit això per permetre que les peces girin automàticament
+         quan xoquin
+        */
+      else if (angleGirPeca != ROTACIO_EXPERT){
+          //rotació de la peça amb angle fix
+         // QPointF finalGir=event->pos()-centrePeca();
+          QPointF finalGir=event->lastPos()-centrePeca();
+          float angleFinal=atan2(finalGir.y(),finalGir.x());
+          int acelera=1;
+          setZValue(20);
+          if (angleFinal<0){angleFinal=angleFinal+2*PI;}
+          //Això és per fer més ràpid el gir en el casos que
+          //l'angle sigui petit;
+          if (event->modifiers().testFlag ( Qt::ControlModifier ) &&
+              angleGirPeca<=15){
+              acelera=2;}
+          //gira en un sentit o altre segons el punt del
+          //clic
+          double girFet;
+          if (angleFinal>PI){
+              rotaPeca(acelera*angleGirPeca*PI/180);
+              girFet=acelera*angleGirPeca*PI/180;
+          }
+          else {
+              rotaPeca(-acelera*angleGirPeca*PI/180);
+              girFet=-acelera*angleGirPeca*PI/180;
+          }
+          //comprova si la peça està en els limits de la zona de joc
+          /* 15/10/11
+             afegit el control de superposició */
+          if(!pecaEnLimits() || pecaSuperposada()) {
+              //if(!pecaEnLimits()){
+              event->ignore();
+              rotaPeca(-girFet);
+              movimentPeca=1;
+          }
+          movimentPeca=1;
       }
-      
-   }//final if contains
+ /*
+   }//final if contains  23/07/11
   else {
      //Això per evitar que la peça quedi "seleccionada" quan el curso està fora de la peça
      setSelected(false);
      event->ignore();
     // setZValue(-1);
      movimentPeca=0;
- }
+ }*/
 }
 else {
      event->ignore();
@@ -271,9 +357,18 @@ void Peca::mouseReleaseEvent(QGraphicsSceneMouseEvent *event){
        QPointF distancia;
        distancia= aferraPeca();
        setPos(pos()-distancia);
+       /* 15/10/11
+          Es controla que la peça no quedi superposada
+          allunyant-la desprès d'aferrar-la.
+          13/11/11
+          Això provoca un bucle infinit en
+          algunes situacions
+       while(pecaSuperposada()){
+        setPos(pos()+distancia*0.01);
+       }*/
    }
 }
-// printf("Mouse release de Peça");
+
  //deseleccionam la Peça
  setSelected(false);
  setFlag(QGraphicsItem::ItemIsMovable,false);
@@ -286,8 +381,11 @@ void Peca::mouseReleaseEvent(QGraphicsSceneMouseEvent *event){
 
 /*
   Calcula el trasllat necessari per
-  "aferrar" la peça a la més propera
-  AIxò queda aparcat (¿?)
+  "aferrar" la peça a la més propera.
+  Primer es comproven els vertex de la peça
+  i, si no és possible "aferrar-la" llavors
+  s'itenta fer el mateix amb els costats
+  (amb el procediment aferraPeca2)
 */
 QPointF Peca::aferraPeca(){
  QVector<QPointF> aquestaPeca;
@@ -296,6 +394,7 @@ QPointF Peca::aferraPeca(){
  float distancia, distanciaActual;
  puntsVertexPeca(aquestaPeca);
  desplacament=QPointF(0,0);
+ bool aferrada=false;
  for(int i=0;i<=conjuntDePeces->arrayPeces.size()-1;i++){
      if(!(this->indexEnElConjunt == conjuntDePeces->arrayPeces[i]->indexEnElConjunt) ){
         conjuntDePeces->arrayPeces[i]->puntsVertexPeca(altraPeca);
@@ -307,14 +406,61 @@ QPointF Peca::aferraPeca(){
                 if( (distanciaActual<distancia) && (distanciaActual<=5.0) ){
                    distancia=distanciaActual;
                    desplacament=despActual;
+                   aferrada=true;
                 }
             }
         }
      }
     }
-return desplacament;
+ if(aferrada){
+     return desplacament;
+   }
+ else return aferraPeca2();
+//return desplacament;
 }
 
+/*
+  "Aferra" la peça actual pels costats
+  */
+QPointF Peca::aferraPeca2(){
+ QPointF desplacament, despActual;
+ float distancia, distanciaActual,distanciaRecorreguda;
+
+ desplacament=QPointF(0,0);
+ distanciaActual=0.0;
+ distanciaRecorreguda=0.0;
+ QPointF posicioInicial=pos();
+ for(int i=0;i<conjuntDePeces->arrayPeces.size();i++){
+     float vector=0.0;
+     int valor=0;
+     distanciaRecorreguda=0.0;
+     distancia=100000;
+     QPointF vectorCentres=(conjuntDePeces->arrayPeces[i]->centreRectanglePeca()+
+                           conjuntDePeces->arrayPeces[i]->pos())-
+                           (centreRectanglePeca()+pos());
+     if(indexEnElConjunt != conjuntDePeces->arrayPeces[i]->indexEnElConjunt){
+         while( (distanciaRecorreguda<8.0) &&  !pecaSuperposada(false) ){
+         setPos(pos()+vectorCentres*vector);
+         distanciaRecorreguda=sqrt(pow((posicioInicial-pos()).x(),2)+pow((posicioInicial-pos()).y(),2));
+         valor++;
+         vector=((float) valor)/((float) 10000);
+        }
+         if(pecaSuperposada(false)){
+             //El 0.90 per evitar que quedin una mica superposades
+             //Això també depén del 10000 del vector
+             despActual=(posicioInicial-pos())*0.9;
+             distanciaActual=sqrt(pow(despActual.x(),2)+pow(despActual.y(),2));
+         }
+   }//final if del index del conjunt
+ setPos(posicioInicial);
+ if(distanciaActual<distancia){
+   desplacament=despActual ;
+   distancia=distanciaActual;
+  }
+ }//final for de les peces del conjunt
+
+return desplacament;
+}
 
 //determina si la peça està en els límits de l'escena
 bool Peca::pecaEnLimits(){
@@ -329,18 +475,26 @@ bool Peca::pecaEnLimits(){
 return enLimits;
 }//final Peca::pecaEnLimits()
 
-//determina si la peça està superposada amb una altra
-//Peró això de collidesWithPath no fa el que s'espera!!!
-//Nomes controla la col·lisió del boundingRect no del Path!!!
-bool Peca::pecaSuperposada(){
-    QList<QGraphicsItem *> pecesSuperposades=collidingItems(Qt::IntersectsItemShape);
+/* 15/10/11
+determina si la peça xoca amb una altra
+*/
+bool Peca::pecaSuperposada(bool controlInfantil){
+    //això restringeix la funció als nivells
+    //iniciat i expert
+    //if (angleGirPeca != ROTACIO_EXPERT){ return false;}
+    if( (nivellJoc==NIVELL_INFANTIL) &&
+        controlInfantil){return false;}
     bool xoca=false;
-    foreach (QGraphicsItem *item, pecesSuperposades) {
-      if (!xoca  && this != item){
-         // xoca=collidesWithItem(item,Qt::IntersectsItemShape);
-         xoca=this->collidesWithPath(item->shape(),Qt::IntersectsItemBoundingRect);
-       //  xoca=this->collidesWithPath(item->shape(),Qt::IntersectsItemShape);
-          }
+    for(int j=0;j<conjuntDePeces->arrayPeces.size();j++){
+        if (conjuntDePeces->arrayPeces[j] != this){
+            if(conjuntDePeces->arrayPeces[j]->shape().translated(
+                  conjuntDePeces->arrayPeces[j]->pos())
+                .intersects(
+                    this->shape().translated(
+                          this->pos()))){
+            xoca=true;
+            }
+        }
     }
   return xoca;
 }//final Peca::pecaSuperposada()
@@ -521,12 +675,13 @@ void Peca::puntsSolucio(QVector<QPointF> &pSol,float reduccio){
       no funciona això (es queda dins el while degut a què
       no s'aconsegueixen els punt addicionals)
      */
+   /* 01/01/12  Eliminat: no pareix que serveixi de gran cosa això
    if( (tipusPeca !=62) && (tipusPeca != 67) && (tipusPeca != 68)){
-   int puntsAddicionals=0;
+   int puntsAddicionals=3;
    //for(int i=0;i<=9;i++){
+  qsrand(rellotgeQTime.msecsTo(QTime::currentTime()));
   for(int i=0;i<=numeroVertex-1;i++){
-   while (puntsAddicionals<3){
-      qsrand(rellotgeQTime.msecsTo(QTime::currentTime()));
+   while (puntsAddicionals<3){      
       int numVertex=qrand() % numeroVertex;
       QPointF puntAddicional(
            (1/pow(5,puntsAddicionals+1))*reduccio*escala*modulsVertex.value(numVertex)*cos(anglesVertex.value(numVertex)),
@@ -538,7 +693,7 @@ void Peca::puntsSolucio(QVector<QPointF> &pSol,float reduccio){
       }
    }
   }
-}
+}*/
 
  //es pot afegir un punt de l'arc per millorar la correcció
  if (ambArc){
@@ -614,6 +769,48 @@ QPainterPath Peca::shape()
     return polygonPath;
 }//Final Peca::shape
 
+/*
+  Retorna la silueta de la peça però fent servir
+  l'escala passada per paràmetre
+  */
+QPainterPath Peca::shapeEscala(float pescala)
+{
+    //la silueta que retorna la funció i que dibuixa la peça
+    QPainterPath polygonPath;
+    /*calculam el punt central de la peça, en funció del centre
+    del rectangle que ocupa*/
+    QPolygonF polygon;
+    for(int i=0;i<=numeroVertex-1;i++){
+        polygon<<boundingRect().center()+QPointF(
+           pescala*escala*modulsVertex.value(i)*cos(anglesVertex.value(i)),
+           pescala*escala*modulsVertex.value(i)*sin(anglesVertex.value(i)));
+        }
+
+     polygonPath.addPolygon(polygon);
+
+     /*afegim l'arc de la peça (si en té)*/
+     if (ambArc){
+        float iniciArc;
+        iniciArc=0.0;
+        QRectF rectangleArc;
+        rectangleArc=emetArcPeca(iniciArc);
+        QPointF puntActual(polygonPath.currentPosition());
+        polygonPath.arcMoveTo(rectangleArc,(iniciArc-angleArc/2));
+        //polygonPath.arcMoveTo(rectangleArc,(45-iniciArc-angleArc/2));
+        QPointF punt(polygonPath.currentPosition());
+        polygonPath.moveTo(puntActual);
+        QPointF puntFinal(pescala*escala*modulsVertex.value(0)*cos(anglesVertex.value(0)),
+                          pescala*escala*modulsVertex.value(0)*sin(anglesVertex.value(0)) );
+        polygonPath.quadTo(ajustBezier*punt,boundingRect().center()+puntFinal);
+        //aquest moviment és per aconseguir que es tanqui be el dibuix
+        polygonPath.moveTo(puntFinal);
+        }
+    /*tancam el dibuix de la silueta*/
+    polygonPath.closeSubpath();
+
+    return polygonPath;
+}//Final Peca::shape
+
 /*
 Fa els càlculs per dibuixar l'arc de la Peça.
 Retorna el rectangle i modifica els paràmetres
@@ -723,7 +920,7 @@ float Peca::angleArcPeca(){
  return angle;
 }
 
-/*funció obsoleta*/
+/*funció obsoleta 01/01/12 ????*/
 QPointF Peca::centrePeca() const{
 if(numeroVertex<20){
     QPointF centre;
@@ -773,17 +970,36 @@ if (pecaVisible){
 
     painter->drawPath(shape());
 
+
+    //Dibuixa els punts de solució
+    /*
+    pen.setColor(Qt::red);
+        painter->setPen(pen);
+        painter->drawEllipse(centrePeca(),1,1);
+        QVector<QPointF> pSolucio;
+        puntsSolucio(pSolucio,0.9);
+
+    for(int i=0;i<pSolucio.size();i++){
+       painter->drawEllipse(pSolucio.value(i)-pos(),1,1);
+       }
+       */
+
+      /*  painter->drawText(1,1,QString("%1 (%2)").arg(indexEnElConjunt).arg(tipusPeca));
+        painter->drawLine(centrePeca(),
+                          QPointF(escala*modulsVertex.value(0)*cos(anglesVertex.value(0)),
+                                  escala*modulsVertex.value(0)*sin(anglesVertex.value(0))));*/
   //  painter->drawRect(boundingRect());
-/*
+
  //per dibuixar el centre de la peça
+    /*
  QPointF centreD;
 QPointF centreF=boundingRect().center();
    centreD=centrePeca();
    painter->setBrush(Qt::red);
    painter->drawPoint(centreD);
    painter->setBrush(Qt::black);
-   painter->drawPoint(centreF);
- */
+   painter->drawPoint(centreF);*/
+
   }
 }//Final Peca::Paint
 
@@ -864,6 +1080,8 @@ void Peca::creaPeca(int pintPeca){
   movimentPeca=0;
   //inicialment el gir és lliure
   angleGirPeca=1.0;
+  //Nivell del joc actual
+  nivellJoc=NIVELL_INFANTIL;
 
   QString dadesPeces=recuperaDadesPeca();
   //QString dadesPeces=llegeixLiniaArxiu(
