@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2011  Innocent De Marchi
+ * Copyright (C) 2000-2012  Innocent De Marchi
  * email: tangram.peces@gmail.com
  *
  * This program is free software; you can redistribute it and/or modify
@@ -65,6 +65,13 @@ public:
     */
     int movimentPeca;
 
+    /*
+      Nivell del joc
+      Es fa servir per eliminar l'efecte de xoc entre
+      les peces al nivell infantil
+      */
+     int nivellJoc;
+
 
 	
     Peca(); //constructor per defecte
@@ -89,6 +96,10 @@ public:
       */
     QString recuperaDadesPeca();
     
+
+    /* 15/10/11
+       Aquest procediment no es fa servir
+    */
     void colocaPecaAtzar(int maxX,int maxY);
     void colocaPecaAtzar();
     /*
@@ -102,6 +113,7 @@ public:
     
     /* Silueta de la peça*/
     QPainterPath shape() ;
+    QPainterPath shapeEscala(float pescala);
 
     /* Punts per controlar la solució*/
     void puntsSolucio(QVector<QPointF> &pSol,float reduccio=1.0);
@@ -225,6 +237,26 @@ public:
     bool pecaEnLimits();
 
 
+    /* 15/10/11
+    determina si la peça xoca amb una altra
+    14/11/11
+    S'ha passat a públic pel tema de la generació
+    de figures a l'atzar
+    */
+    bool pecaSuperposada(bool controlInfantil=true);
+
+    /*
+    Calcula el trasllat necessari per
+    "aferrar" la peça a la més propera
+    14/11/11
+    S'ha passat a públic pel tema de la generació
+    de figures a l'atzar
+    */
+    QPointF aferraPeca();
+    /*
+      Intenta "aferrar" la peça pels costats
+      */
+    QPointF aferraPeca2();
 
  protected:
  	void mousePressEvent(QGraphicsSceneMouseEvent *event);
@@ -315,19 +347,12 @@ public:
     */
     float angleArcPeca();
 
-    //determina si la peça està superposada amb una altra
-    bool pecaSuperposada();
     
 //innecessari    
     //QRectF outlineRect() const ;
 
 
 
-    /*
-    Calcula el trasllat necessari per
-    "aferrar" la peça a la més propera
-    */
-    QPointF aferraPeca();
 
  //Cadena amb les dades de la peca
  QString dadesDeLaPeca;
